# wallet-eth

一个简单的基于Python的以太坊命令行客户端

- 基于fire/web3py
- 支持监听transfer转账事件
- 支持私钥导入、助记词导入
- 支持以太坊转账、ERC20转账
- 支持自定义网络

---

三个模块:

wallet 钱包私钥导入导出相关操作
token 余额查询、转账相关操作
tool 网络更换

```bash

Usage

    wallet token/tool/wallet show/crate/recover ...

Parameters

    token
        token类 add(添加代币)、balance(获取余额)、get_list(获取列表)、send(发送交易)、event(监听转账)
    tool
        tool类 current(获取当前网络)、set(更换网络)
    wallet
        wallet类 show(查看钱包)、crate(创建钱包)、recover(恢复钱包)

```
